@@ -6,7 +6,7 @@ NULL
 
 #' @title HSLuv color specification
 #' @description Converts a color given in HSLuv coordinates to a hexadecimal 
-#'   string or a RGB color specification  
+#'   string or a RGB color specification.
 #'
 #' @param h the hue, a number between \code{0} and \code{360}
 #' @param s the saturation, a number between \code{0} and \code{100}
@@ -60,7 +60,7 @@ hsluv2rgb <- function(h = 360, s = 100, l = 100){
 
 #' @title HSL color specification
 #' @description Converts a color given in HSL coordinates to a hexadecimal 
-#'   string  
+#'   string.
 #'
 #' @param h the hue, a number between \code{0} and \code{360}
 #' @param s the saturation, a number between \code{0} and \code{100}
@@ -104,3 +104,51 @@ hsl <- function(h = 360, s = 100, l = 100, alpha = NULL){
     hsl_alpha_cpp(h, s, l, alpha)
   }
 }
+
+
+#' @title HSI color specification
+#' @description Converts a color given in HSI coordinates to a hexadecimal 
+#'   string.
+#'
+#' @param h the hue, a number between \code{0} and \code{360}
+#' @param s the saturation, a number between \code{0} and \code{100}
+#' @param i the intensity, a number between \code{0} and \code{100}
+#' @param alpha opacity, a number between \code{0} and \code{1}, 
+#'   or \code{NULL} 
+#'
+#' @return The \code{hsi} function returns a hexadecimal string representing 
+#'   the corresponding color.
+#' @export
+#'
+#' @examples
+#' saturation <- 100
+#' f <- Vectorize(
+#'   function(x, y){
+#'     z <- complex(real = x, imaginary = y)
+#'     modulus <- Mod(z)
+#'     if(modulus > 1){
+#'       return("#ffffff")
+#'     }
+#'     radians <- Arg(z)
+#'     if(radians < 0){
+#'       radians <- radians + 2*pi
+#'     }
+#'     degrees <- 360 * radians / 2 / pi
+#'     hsi(h = degrees, s = saturation, i = 100*modulus)
+#'   }
+#' )
+#' 
+#' x <- y <- seq(-1, 1, length.out = 200L)
+#' image <- outer(x, y, f)
+#' 
+#' opar <- par(mar = c(0, 0, 0, 0))
+#' plot(NULL, xlim = c(-1, 1), ylim = c(-1, 1), asp = 1)
+#' rasterImage(image, -1, -1, 1, 1)
+#' par(opar)
+hsi <- function(h = 360, s = 100, i = 100, alpha = NULL){
+  if(is.null(alpha)) {
+    hsi_cpp(h, s, i)
+  } else {
+    hsi_alpha_cpp(h, s, i, alpha)
+  }
+}
